[tor-commits] [tor/master] Try to fix an intermittent test failure on openbsd.

nickm at torproject.org nickm at torproject.org
Tue Mar 22 13:13:08 UTC 2016


commit dae8484107282edde19c766aeb8713dbdcdb03b4
Author: Nick Mathewson <nickm at torproject.org>
Date:   Tue Mar 22 09:12:59 2016 -0400

    Try to fix an intermittent test failure on openbsd.
---
 src/test/test_scheduler.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/test/test_scheduler.c b/src/test/test_scheduler.c
index 977ce6f..6e9889b 100644
--- a/src/test/test_scheduler.c
+++ b/src/test/test_scheduler.c
@@ -461,11 +461,11 @@ test_scheduler_compare_channels(void *arg)
 
   /*
    * This is to test the different-policies case, which uses the policy
    * cast to an intptr_t as an arbitrary but definite thing to compare.
    */
   mock_cgp_val_1 = tor_malloc_zero(16);
   mock_cgp_val_2 = tor_malloc_zero(16);
-  if ( ((intptr_t) mock_cgp_val_1) > ((intptr_t) mock_cgp_val_2) ) {
+  if ( ((uintptr_t) mock_cgp_val_1) > ((uintptr_t) mock_cgp_val_2) ) {
     void *tmp = mock_cgp_val_1;
     mock_cgp_val_1 = mock_cgp_val_2;
     mock_cgp_val_2 = tmp;
@@ -461,11 +461,11 @@ test_scheduler_compare_channels(void *arg)
   /*
    * This is to test the different-policies case, which uses the policy
-   * cast to an intptr_t as an arbitrary but definite thing to compare.
+   * cast to an uintptr_t as an arbitrary but definite thing to compare.
    */
   mock_cgp_val_1 = tor_malloc_zero(16);



More information about the tor-commits mailing list